import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:http/http.dart' as http;
import 'package:intl/intl.dart';
import 'package:flutter_dotenv/flutter_dotenv.dart';
import 'package:textfield_tags/textfield_tags.dart';

import 'dart:convert';
import 'dart:io';

import 'ItemMenu.dart';
import '../classes/alert.dart';
import '../classes/eventAdded.dart';

import '../variable/globals.dart' as globals;

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  Map<String, dynamic> events = {};
  String id = "";
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: EditEvent(id: id),
    );
  }
}

class EditEvent extends StatefulWidget {
  const EditEvent({Key? key, required this.id}) : super(key: key);
  final String id;

  @override
  _EditEventState createState() => _EditEventState();
}

class _EditEventState extends State<EditEvent>
    with ShowErrorDialog, ShowEventDialog {
  TextEditingController inputName = TextEditingController();

  TextEditingController inputDate = TextEditingController();
  TextEditingController inputDesc = TextEditingController();

  TextEditingController inputGeo = TextEditingController();

  TextEditingController startDatepicker = TextEditingController();
  TextEditingController startTimepicker = TextEditingController();
  TextEditingController endDatepicker = TextEditingController();
  TextEditingController endTimepicker = TextEditingController();
  final _stringTagController = StringTagController();

  DateTime startDate = DateTime.now();
  DateTime endDate = DateTime.now();
  List<Map<String, dynamic>> suggestions = [];
  String geographicalZone = "";
  String imgUrl = "";
  Map<String, dynamic> events = {};

  List<String> initialTags = [];

  final _stringOrgaController = StringTagController();
  List<String> initialOrga = [];

  onTapFunctionDatePicker(
      {required BuildContext context, required String position}) async {
    DateTime date;
    if ((startDatepicker.text.isEmpty) || (endDatepicker.text.isEmpty)) {
      date = DateTime.now();
    } else {
      date = DateTime.parse(formatDate(startDatepicker.text));
      if (position == "end") {
        date = DateTime.parse(formatDate(endDatepicker.text));
      }
    }
    DateTime? pickedDate = await showDatePicker(
        context: context,
        firstDate: date,
        initialDate: date,
        lastDate: DateTime(2104));
    if (pickedDate == null) return;
    if (position == "start") {
      startDatepicker.text = DateFormat("dd/MM/yyyy").format(pickedDate);
    }
    if (position == "end") {
      endDatepicker.text = DateFormat("dd/MM/yyyy").format(pickedDate);
    }
  }

  onTapFunctionTimePicker(
      {required BuildContext context, required String position}) async {
    TimeOfDay time;

    if ((startTimepicker.text.isEmpty) || (endTimepicker.text.isEmpty)) {
      time = TimeOfDay.now();
    } else {
      DateTime date = new DateTime.now();
      date = date.copyWith(
          hour: int.parse(startTimepicker.text.split(":")[0]),
          minute: int.parse(startTimepicker.text.split(":")[1]));
      time = TimeOfDay.fromDateTime(date);
      if (position == "end") {
        date = date.copyWith(
            hour: int.parse(endTimepicker.text.split(":")[0]),
            minute: int.parse(endTimepicker.text.split(":")[1]));
        time = TimeOfDay.fromDateTime(date);
      }
    }

    TimeOfDay? pickedDate =
        await showTimePicker(context: context, initialTime: time);
    if (pickedDate == null) return;
    if (position == "start") {
      startTimepicker.text = pickedDate.format(context);
    }
    if (position == "end") {
      endTimepicker.text = pickedDate.format(context);
    }
  }

  convertNulltoEmptyString(var check) {
    if (check == null) {
      return "";
    }
    return check;
  }

  convertNulltoArray(List<String> check) {
    if (check == null) {
      return [];
    }
    return check;
  }

  String formatDate(String date) {
    var splitedDate = date.split("/");

    var day = splitedDate[0];
    var month = splitedDate[1];
    var year = splitedDate[2];

    return "${year}-${month}-${day}";
  }

  Future<void> _getEventInfos() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var accessToken = prefs.getString("access_token") ?? "";
    String formerName = "";
    String formerMap = "";
    String formerImage = "";
    String formerDesc = "";
    List<String> formerTags = [];
    List<String> formerOrga = [];

    if (accessToken.isNotEmpty) {
      var urlGet = Uri.parse("${globals.api}/events/${widget.id}");

      var responseGet = await http.get(urlGet,
          headers: {HttpHeaders.cookieHeader: 'access_token=${accessToken}'});
      stderr.writeln('Response Get status: ${responseGet.statusCode}');
      if (responseGet.statusCode == 200) {
        stderr.writeln('Username : ${responseGet.body}');
        events = jsonDecode(utf8.decode(responseGet.bodyBytes));
        formerName = convertNulltoEmptyString(events["name"]);
        formerMap = convertNulltoEmptyString(events["place"]);
        formerDesc = convertNulltoEmptyString(events["description"]);

        startDate = DateTime.parse(events["start_date"]);

        endDate = DateTime.parse(events["end_date"]);

        if (events["imgUrl"] != null) {
          formerImage = events["imgUrl"];
        }
      } else {
        var text = "";
        switch (responseGet.statusCode) {
          case 400:
            {
              text = "Requête mal construite";
            }
            break;
          case 406:
            {
              text = "Mot de passe incorrect";
            }
            break;
          case 404:
            {
              text = "Utilisateur inconnu";
            }
            break;
          case 403:
            {
              text = "Vous n'avez pas l'autorisation de faire cette action";
            }
            break;
          case 410:
            {
              text = "Token invalide";
            }
            break;
          case 500:
            {
              text = "Probleme interne du serveur";
            }
            break;
          default:
            {
              text = "Probleme d'authentification inconnu";
            }
            break;
        }
        showErrorDialog(context, text);
      }
    } else {
      showErrorDialog(context, "Cache invalide");
    }

    setState(() {
      // This call to setState tells the Flutter framework that something has
      // changed in this State, which causes it to rerun the build method below
      // so that the display can reflect the updated values. If we changed
      // _counter without calling setState(), then the build method would not be
      // called again, and so nothing would appear to happen.
      inputName.text = formerName;
      startDatepicker.text =
          DateFormat("dd/MM/yyyy").format(startDate).toString();
      startTimepicker.text = DateFormat("HH:mm").format(startDate).toString();
      endDatepicker.text = DateFormat("dd/MM/yyyy").format(endDate).toString();
      endTimepicker.text = DateFormat("HH:mm").format(endDate).toString();
      inputGeo.text = formerMap;
      imgUrl = formerImage;
      inputDesc.text = formerDesc;
      for (int i = 0; i < events["tags"].length; i++) {
        _stringTagController.addTag(events["tags"][i]);
      }
      for (int i = 0; i < events["organizers"].length; i++) {
        _stringOrgaController.addTag(events["organizers"][i]);
      }
    });
  }

  Future<void> _updateEvent(BuildContext context) async {
    var name = inputName.text;
    var place = inputGeo.text;
    var description = inputDesc.text;
    List<String> tags = List<String>.from(_stringTagController.getTags as List);
    List<String> organizers =
        List<String>.from(_stringOrgaController.getTags as List);

    var startDateFormat = formatDate(startDatepicker.text);
    DateTime startDateCompare = DateTime.parse(startDateFormat);
    DateTime dateNow = DateTime.now();
    var endDateFormat = formatDate(endDatepicker.text);
    var startDate =
        "${startDateFormat}T${startTimepicker.text.replaceAll('-', ':')}";
    var endDate = "${endDateFormat}T${endTimepicker.text.replaceAll('-', ':')}";
    if (startDateCompare.isAfter(dateNow)) {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      var accessToken = prefs.getString("access_token") ?? "";

      if (accessToken.isNotEmpty) {
        try {
          await dotenv.load();
          final mapboxAccessToken = dotenv.env['MAPBOX_ACCESS_TOKEN'] ?? '';
          print("place non encoded : ${place}");
          final url =
              'https://api.mapbox.com/geocoding/v5/mapbox.places/${place}.json?access_token=${mapboxAccessToken}&types=poi,address,place';
          var encoded = Uri.encodeFull(url);
          print("encoded : ${encoded}");
          final response = await http.get(Uri.parse(encoded));

          if (response.statusCode == 200) {
            final data = json.decode(response.body);
            print("data : ${data}");

            if (data['features'].isNotEmpty) {
              place = data['features'][0]['place_name'];
              final coordinates =
                  data['features'][0]['geometry']['coordinates'];
              final longitude = coordinates[0]; // Longitude
              final latitude = coordinates[1]; // Latitude
              var urlGet = Uri.parse(
                  "${globals.api}/events/search?item=${name}&date_event=${startDate}");

              var responseGet = await http.get(urlGet, headers: {
                HttpHeaders.cookieHeader: 'access_token=${accessToken}'
              });
              if (responseGet.statusCode == 200) {
                var events = jsonDecode(utf8.decode(responseGet.bodyBytes));
                print("reponse  http : ${events.length}");
                if (events.length == 0) {
                  urlGet = Uri.parse(
                      "${globals.api}/events/search?min_lat=$latitude&max_lat=$latitude"
                      "&min_lon=$longitude&max_lon=$longitude&date_event=${startDate}");
                  responseGet = await http.get(urlGet, headers: {
                    HttpHeaders.cookieHeader: 'access_token=${accessToken}'
                  });
                  if (responseGet.statusCode == 200) {
                    events = jsonDecode(utf8.decode(responseGet.bodyBytes));
                    print("reponse  http : ${events.length}");
                    if (events.length != 0) {
                      Navigator.push(
                          context,
                          MaterialPageRoute(
                              builder: (_) =>
                                  ItemMenu(title: events[0]["id"])));
                      return;
                    }
                  }
                } else {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (_) => ItemMenu(title: events[0]["id"])));
                  return;
                }
              }

              final params = {
                'expiration': '15552000',
                'key': dotenv.env["IMGBB_API_KEY"],
              };
              print("Post Img");
              final urlPost = Uri.parse('https://api.imgbb.com/1/upload')
                  .replace(queryParameters: params);

              final req = http.MultipartRequest('POST', urlPost);

              final stream = await req.send();
              final res = await http.Response.fromStream(stream);

              final status = res.statusCode;
              print("code status imgbb ${status}");
              if (status == 200) {
                var body = json.decode(utf8.decode(res.bodyBytes));
                String imgUrl = body["data"]["url"];

                //String credentials = "${pseudo}:${password}";
                //Codec<String, String> stringToBase64 = utf8.fuse(base64);
                //String encoded = stringToBase64.encode(credentials);
                var urlPut = Uri.parse("${globals.api}/events");
                var responsePut = await http.put(urlPut,
                    headers: {
                      HttpHeaders.cookieHeader: 'access_token=${accessToken}',
                      HttpHeaders.acceptHeader:
                          'application/json, text/plain, */*',
                      HttpHeaders.contentTypeHeader: 'application/json'
                    },
                    body: jsonEncode({
                      'name': name,
                      'place': place,
                      'start_date': startDate,
                      'end_date': endDate,
                      'organizers': organizers,
                      'latitude': latitude,
                      'longitude': longitude,
                      'description': description,
                      "imgUrl": imgUrl,
                      "tags": tags
                    }));
                print(responsePut.statusCode);
                if ((responsePut.statusCode == 200) ||
                    (responsePut.statusCode == 201)) {
                  showEventDialog(context, "Evenement ${name} ajoute");
                } else {
                  var text = "";
                  switch (responsePut.statusCode) {
                    case 400:
                      {
                        text = "Requête mal construite";
                      }
                      break;
                    case 406:
                      {
                        text = "Mot de passe incorrect";
                      }
                      break;
                    case 404:
                      {
                        text = "Utilisateur inconnu";
                      }
                      break;
                    case 403:
                      {
                        text = "Utilisateur desactive";
                      }
                      break;
                    case 410:
                      {
                        text = "Token invalide";
                      }
                      break;
                    case 500:
                      {
                        text = "Probleme interne du serveur";
                      }
                      break;
                    default:
                      {
                        text = "Probleme d'authentification inconnu";
                      }
                      break;
                  }
                  showErrorDialog(context, text);
                }
              } else {
                print("imgbb error : ${status}");
              }
            } else {
              showErrorDialog(context, "Aucune donnée geographique");
            }
          } else {
            showErrorDialog(context, "Mapbox non accessible");
          }
        } catch (e) {
          showErrorDialog(context, "${e}");
        }
      } else {
        showErrorDialog(context, "Champ vide");
      }
    } else {
      showErrorDialog(context, "Evenement non futur");
    }
  }

  @override
  void initState() {
    _getEventInfos();
    super.initState();
  }

  final _formKey = GlobalKey<FormState>();
  String? _validateField(String? value) {
    return value!.isEmpty ? 'Champ requis' : null;
  }

  Future<void> searchSuggestions(String input) async {
    await dotenv.load(fileName: ".env"); // Load .env file

    final mapboxAccessToken = dotenv.env['MAPBOX_ACCESS_TOKEN'] ?? '';
    final url =
        'https://api.mapbox.com/geocoding/v5/mapbox.places/${input}.json?access_token=${mapboxAccessToken}&types=poi,address,place';
    var encoded = Uri.encodeFull(url);
    final response = await http.get(Uri.parse(encoded));
    print("response code suggesttion : ${response.statusCode}");

    if (response.statusCode == 200) {
      final data = json.decode(response.body);
      print("data suggestion : ${data}");
      setState(() {
        suggestions = (data['features'] as List)
            .map((feature) => {
                  'place_name': feature['place_name'],
                  'text': feature['text'],
                  'geometry': feature[
                      'geometry'], // Include geometry for latitude/longitude
                })
            .toList();
      });
    } else {
      throw Exception('Failed to load suggestions');
    }
  }

  Padding _buildGeographicalZoneSearchField() {
    return Padding(
      padding:
          const EdgeInsets.only(left: 15.0, right: 15.0, top: 15, bottom: 0),
      child: Column(
        children: [
          TextField(
            controller: inputGeo,
            decoration: InputDecoration(
              labelText: 'Lieu',
              border: OutlineInputBorder(),
              suffixIcon: IconButton(
                icon: const Icon(Icons.clear),
                onPressed: () {
                  setState(() {
                    inputGeo.clear(); // Clear the text field
                    geographicalZone = ''; // Reset the geographical zone state
                    suggestions.clear(); // Optionally clear suggestions
                  });
                },
              ),
            ),
            onChanged: (value) {
              setState(() {
                geographicalZone = value;
                searchSuggestions(value);
              });
            },
          ),
          if (suggestions.isNotEmpty)
            Container(
              height: 200,
              decoration: BoxDecoration(
                border: Border.all(color: Colors.blue),
                borderRadius: BorderRadius.circular(8),
              ),
              child: ListView.builder(
                shrinkWrap: true,
                itemCount: suggestions.length,
                itemBuilder: (context, index) {
                  return ListTile(
                    title: Text(suggestions[index]['text']),
                    subtitle: Text(suggestions[index]['place_name']),
                    onTap: () async {
                      print("suggestion tapped : ${suggestions[index]}");
                      final latitude =
                          suggestions[index]['geometry']['coordinates'][1];
                      final longitude =
                          suggestions[index]['geometry']['coordinates'][0];

                      setState(() {
                        geographicalZone = suggestions[index]['text'];
                        inputGeo.text = geographicalZone;
                        suggestions.clear();
                      });
                    },
                  );
                },
              ),
            ),
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: Text("Add or Update a event"),
          backgroundColor: Colors.blue,
          foregroundColor: Colors.white,
        ),
        body: Form(
          key: _formKey,
          child: SingleChildScrollView(
            child: Column(
              children: <Widget>[
                Padding(
                    padding: const EdgeInsets.only(top: 60.0),
                    child: Image.network(
                      imgUrl,
                      width: MediaQuery.of(context).size.width *
                          0.5, // 50% of screen width
                      height: MediaQuery.of(context).size.height * 0.5,
                      loadingBuilder: (BuildContext context, Widget child,
                          ImageChunkEvent? loadingProgress) {
                        if (loadingProgress == null) {
                          return child; // The image has finished loading
                        }
                        return Center(
                          child: CircularProgressIndicator(),
                        );
                      },
                      errorBuilder: (BuildContext context, Object error,
                          StackTrace? stackTrace) {
                        return Center(
                          child: Icon(Icons.error,
                              size: MediaQuery.of(context).size.width * 0.1),
                        );
                      },
                    )),
                Padding(
                  //padding: const EdgeInsets.only(left:15.0,right: 15.0,top:0,bottom: 0),
                  padding: EdgeInsets.symmetric(horizontal: 15),
                  child: TextFormField(
                    controller: inputName,
                    validator: (value) => _validateField(value),
                    decoration: InputDecoration(
                        border: OutlineInputBorder(),
                        labelText: 'Nom',
                        hintText: 'Modifier le nom de l\'évènement'),
                  ),
                ),
                _buildGeographicalZoneSearchField(),
                Padding(
                  padding: const EdgeInsets.only(
                      left: 15.0, right: 15.0, top: 15, bottom: 0),
                  //padding: EdgeInsets.symmetric(horizontal: 15),
                  child: TextFormField(
                      controller: startDatepicker,
                      readOnly: true,
                      validator: (value) => _validateField(value),
                      decoration: InputDecoration(
                          border: OutlineInputBorder(),
                          labelText: 'Date de debut',
                          hintText: 'Cliquez ici pour selectionner une date'),
                      onTap: () => onTapFunctionDatePicker(
                          context: context, position: "start")),
                ),
                Padding(
                  padding: const EdgeInsets.only(
                      left: 15.0, right: 15.0, top: 15, bottom: 0),
                  //padding: EdgeInsets.symmetric(horizontal: 15),
                  child: TextFormField(
                      controller: startTimepicker,
                      readOnly: true,
                      validator: (value) => _validateField(value),
                      decoration: InputDecoration(
                          border: OutlineInputBorder(),
                          labelText: 'Heure de debut',
                          hintText: 'Cliquez ici pour selectionner une heure'),
                      onTap: () => onTapFunctionTimePicker(
                          context: context, position: "start")),
                ),
                Padding(
                  padding: const EdgeInsets.only(
                      left: 15.0, right: 15.0, top: 15, bottom: 0),
                  //padding: EdgeInsets.symmetric(horizontal: 15),
                  child: TextFormField(
                      controller: endDatepicker,
                      readOnly: true,
                      validator: (value) => _validateField(value),
                      decoration: InputDecoration(
                          border: OutlineInputBorder(),
                          labelText: 'Date de fin',
                          hintText: 'Cliquez ici pour selectionner une date'),
                      onTap: () => onTapFunctionDatePicker(
                          context: context, position: "end")),
                ),
                Padding(
                  padding: const EdgeInsets.only(
                      left: 15.0, right: 15.0, top: 15, bottom: 0),
                  //padding: EdgeInsets.symmetric(horizontal: 15),
                  child: TextFormField(
                      controller: endTimepicker,
                      readOnly: true,
                      validator: (value) => _validateField(value),
                      decoration: InputDecoration(
                          border: OutlineInputBorder(),
                          labelText: 'Heure de fin',
                          hintText: 'Cliquez ici pour selectionner une heure'),
                      onTap: () => onTapFunctionTimePicker(
                          context: context, position: "end")),
                ),
                TextFieldTags<String>(
                    textfieldTagsController: _stringTagController,
                    initialTags: initialTags,
                    textSeparators: const [' ', ','],
                    validator: (String tag) {
                      if (_stringTagController.getTags!.contains(tag)) {
                        return 'Tu as deja rentre ce tag';
                      }
                      return null;
                    },
                    inputFieldBuilder: (context, inputFieldValues) {
                      return Padding(
                        padding: const EdgeInsets.only(
                            left: 15.0, right: 15.0, top: 15, bottom: 0),
                        child: TextField(
                          controller: inputFieldValues.textEditingController,
                          focusNode: inputFieldValues.focusNode,
                          onChanged: inputFieldValues.onTagChanged,
                          onSubmitted: inputFieldValues.onTagSubmitted,
                          decoration: InputDecoration(
                            border: OutlineInputBorder(),
                            labelText: 'Tags',
                            hintText: inputFieldValues.tags.isNotEmpty
                                ? ''
                                : "Enter tag...",
                            errorText: inputFieldValues.error,
                            prefixIcon: inputFieldValues.tags.isNotEmpty
                                ? SingleChildScrollView(
                                    controller:
                                        inputFieldValues.tagScrollController,
                                    scrollDirection: Axis.vertical,
                                    child: Padding(
                                      padding: const EdgeInsets.only(
                                        top: 8,
                                        bottom: 8,
                                        left: 8,
                                      ),
                                      child: Wrap(
                                          runSpacing: 4.0,
                                          spacing: 4.0,
                                          children: inputFieldValues.tags
                                              .map((String tag) {
                                            return Container(
                                              decoration: const BoxDecoration(
                                                borderRadius: BorderRadius.all(
                                                  Radius.circular(20.0),
                                                ),
                                                color: Colors.blue,
                                              ),
                                              margin:
                                                  const EdgeInsets.symmetric(
                                                      horizontal: 5.0),
                                              padding:
                                                  const EdgeInsets.symmetric(
                                                      horizontal: 10.0,
                                                      vertical: 5.0),
                                              child: Row(
                                                mainAxisAlignment:
                                                    MainAxisAlignment.start,
                                                mainAxisSize: MainAxisSize.min,
                                                children: [
                                                  InkWell(
                                                    child: Text(
                                                      '$tag',
                                                      style: const TextStyle(
                                                          color: Colors.white),
                                                    ),
                                                    onTap: () {
                                                      //print("$tag selected");
                                                    },
                                                  ),
                                                  const SizedBox(width: 4.0),
                                                  InkWell(
                                                    child: const Icon(
                                                      Icons.cancel,
                                                      size: 14.0,
                                                      color: Color.fromARGB(
                                                          255, 233, 233, 233),
                                                    ),
                                                    onTap: () {
                                                      inputFieldValues
                                                          .onTagRemoved(tag);
                                                    },
                                                  )
                                                ],
                                              ),
                                            );
                                          }).toList()),
                                    ),
                                  )
                                : null,
                          ),
                        ),
                      );
                    }),
                TextFieldTags<String>(
                    textfieldTagsController: _stringOrgaController,
                    initialTags: initialOrga,
                    textSeparators: const [','],
                    validator: (String tag) {
                      if (_stringOrgaController.getTags!.contains(tag)) {
                        return 'Cet organisateur est déjà rentré';
                      }
                      return null;
                    },
                    inputFieldBuilder: (context, inputFieldValues) {
                      return Padding(
                        padding: const EdgeInsets.only(
                            left: 15.0, right: 15.0, top: 15, bottom: 0),
                        child: TextField(
                          controller: inputFieldValues.textEditingController,
                          focusNode: inputFieldValues.focusNode,
                          onChanged: inputFieldValues.onTagChanged,
                          onSubmitted: inputFieldValues.onTagSubmitted,
                          decoration: InputDecoration(
                            border: OutlineInputBorder(),
                            labelText: 'Organisateurs',
                            hintText: inputFieldValues.tags.isNotEmpty
                                ? ''
                                : "Enter un organisateur...",
                            errorText: inputFieldValues.error,
                            prefixIcon: inputFieldValues.tags.isNotEmpty
                                ? SingleChildScrollView(
                                    controller:
                                        inputFieldValues.tagScrollController,
                                    scrollDirection: Axis.vertical,
                                    child: Padding(
                                      padding: const EdgeInsets.only(
                                        top: 8,
                                        bottom: 8,
                                        left: 8,
                                      ),
                                      child: Wrap(
                                          runSpacing: 4.0,
                                          spacing: 4.0,
                                          children: inputFieldValues.tags
                                              .map((String tag) {
                                            return Container(
                                              decoration: const BoxDecoration(
                                                borderRadius: BorderRadius.all(
                                                  Radius.circular(20.0),
                                                ),
                                                color: Colors.blue,
                                              ),
                                              margin:
                                                  const EdgeInsets.symmetric(
                                                      horizontal: 5.0),
                                              padding:
                                                  const EdgeInsets.symmetric(
                                                      horizontal: 10.0,
                                                      vertical: 5.0),
                                              child: Row(
                                                mainAxisAlignment:
                                                    MainAxisAlignment.start,
                                                mainAxisSize: MainAxisSize.min,
                                                children: [
                                                  InkWell(
                                                    child: Text(
                                                      '$tag',
                                                      style: const TextStyle(
                                                          color: Colors.white),
                                                    ),
                                                    onTap: () {
                                                      //print("$tag selected");
                                                    },
                                                  ),
                                                  const SizedBox(width: 4.0),
                                                  InkWell(
                                                    child: const Icon(
                                                      Icons.cancel,
                                                      size: 14.0,
                                                      color: Color.fromARGB(
                                                          255, 233, 233, 233),
                                                    ),
                                                    onTap: () {
                                                      inputFieldValues
                                                          .onTagRemoved(tag);
                                                    },
                                                  )
                                                ],
                                              ),
                                            );
                                          }).toList()),
                                    ),
                                  )
                                : null,
                          ),
                        ),
                      );
                    }),
                Padding(
                  padding: const EdgeInsets.only(
                      left: 15.0, right: 15.0, top: 15, bottom: 0),
                  //padding: EdgeInsets.symmetric(horizontal: 15),
                  child: TextField(
                    controller: inputDesc,
                    keyboardType: TextInputType.multiline,
                    maxLines: 10,
                    decoration: InputDecoration(
                        border: OutlineInputBorder(),
                        labelText: 'Description',
                        hintText: 'Décrire l\'evènement'),
                  ),
                ),
                SizedBox(
                  height: 30,
                ),
                Container(
                  height: 50,
                  width: 250,
                  decoration: BoxDecoration(
                      color: Colors.blue,
                      borderRadius: BorderRadius.circular(20)),
                  child: TextButton(
                    onPressed: () {
                      if (_formKey.currentState!.validate()) {
                        _updateEvent(context);
                      }
                    },
                    child: Text(
                      'Ajouter',
                      style: TextStyle(color: Colors.white, fontSize: 25),
                    ),
                  ),
                )
              ],
            ),
          ),
        ));
  }
}
